@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the lottie-qt module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "lottieanimation.h"
 
@@ -42,6 +16,7 @@
 #include <QMetaObject>
 #include <QLoggingCategory>
 #include <QThread>
+#include <QQmlContext>
 #include <QQmlFile>
 #include <math.h>
 
@@ -51,6 +26,8 @@
 #include "rasterrenderer/batchrenderer.h"
 #include "rasterrenderer/lottierasterrenderer.h"
 
+using namespace Qt::StringLiterals;
+
 QT_BEGIN_NAMESPACE
 
 Q_LOGGING_CATEGORY(lcLottieQtBodymovinRender, "qt.lottieqt.bodymovin.render");
@@ -76,9 +53,8 @@ Q_LOGGING_CATEGORY(lcLottieQtBodymovinParser, "qt.lottieqt.bodymovin.parser");
     \li Expressions are not supported
     \endlist
 
-    For the full list of devations, please refer to the file
-    \c unsupported_features.txt in the source code.
-
+    For the full list of devations, please see see the \l{Limitations}
+    section.
 
     \section1 Example Usage
 
@@ -341,6 +317,11 @@ int LottieAnimation::currentFrame() const
     return m_currentFrame;
 }
 
+QVersionNumber LottieAnimation::version() const
+{
+    return m_version;
+}
+
 /*!
     \qmlproperty int LottieAnimation::frameRate
 
@@ -599,7 +580,9 @@ void LottieAnimation::load()
 {
     setStatus(Loading);
 
-    m_file.reset(new QQmlFile(qmlEngine(this), m_source));
+    const QQmlContext *context = qmlContext(this);
+    const QUrl loadUrl = context ? context->resolvedUrl(m_source) : m_source;
+    m_file.reset(new QQmlFile(qmlEngine(this), loadUrl));
     if (m_file->isLoading())
         m_file->connectFinished(this, SLOT(loadFinished()));
     else
@@ -679,6 +662,8 @@ int LottieAnimation::parse(QByteArray jsonSource)
     if (Q_UNLIKELY(rootObj.empty()))
         return -1;
 
+    m_version = QVersionNumber::fromString(rootObj.value("v"_L1).toString());
+
     int startFrame = rootObj.value(QLatin1String("ip")).toVariant().toInt();
     int endFrame = rootObj.value(QLatin1String("op")).toVariant().toInt();
     m_animFrameRate = rootObj.value(QLatin1String("fr")).toVariant().toInt();
